import { Module } from '@nestjs/common';
import { CqrsModule } from '@nestjs/cqrs';
import { DatabaseModule } from '../database/database.module';
import { UsersController } from './adapters/primaries/users.controller';
import { UsersRepository } from './adapters/secondaries/users.repository';
import { CreateUserUseCase } from './domain/usecases/create-user.usecase';
import { FindUserByUuidUseCase } from './domain/usecases/find-user-by-uuid.usecase';
import { UpdateUserUseCase } from './domain/usecases/update-user.usecase';
import { UserProfile } from './mappers/user.profile';

@Module({
  imports: [DatabaseModule, CqrsModule],
  controllers: [UsersController],
  providers: [
    UserProfile,
    UsersRepository,
    FindUserByUuidUseCase,
    CreateUserUseCase,
    UpdateUserUseCase,
  ],
  exports: [],
})
export class UsersModule {}
